@@ -9,19 +9,26 @@ setMethod(
   f = "wrap_hull",
   signature = c(x = "MultivariateAnalysis"),
   definition = function(x, margin = 1, axes = c(1, 2), group = NULL) {
+    ## Validation
+    arkhe::assert_scalar(margin, "numeric")
+    arkhe::assert_type(axes, "numeric")
+    arkhe::assert_length(axes, 2)
+
     ## Get coordinates
     data <- get_coordinates(x, margin = margin)
     data <- data[, axes]
+    n <- nrow(data)
 
     ## Add groups, if any
-    k <- get_order(x, margin = margin)
-    if (!is.null(group)) {
-      arkhe::assert_length(group, nrow(data))
-      group <- group[k]
+    if (length(group) > 1) {
+      arkhe::assert_length(group, n)
+      group <- group[get_order(x, margin = margin)]
+    } else if (length(group) == 1) {
+      group <- get_extra(x)[[group]]
     } else if (has_groups(x, margin = margin)) {
       group <- get_groups(x, margin = margin)
     } else {
-      group <- rep("", length(k))
+      group <- rep("", n)
     }
     group <- as.character(group)
 
